.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install stoneredis

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv stoneredis
    $ pip install stoneredis
